https://git.reactos.org/?p=reactos.git;a=commitdiff;h=17b691f5a92dc37dd22ea…
commit 17b691f5a92dc37dd22ea0f62d58e06ff15cdc9c
Author: Amine Khaldi <amine.khaldi(a)reactos.org>
AuthorDate: Sat Dec 23 14:15:02 2017 +0100
[REGEDIT] Rename NUM_ICONS and _CmdWndProc(). #179
---
base/applications/regedit/childwnd.c | 6 +++---
base/applications/regedit/listview.c | 10 +++++-----
2 files changed, 8 insertions(+), 8 deletions(-)
diff --git a/base/applications/regedit/listview.c b/base/applications/regedit/listview.c
index 687fb2234b..9d89173e62 100644
--- a/base/applications/regedit/listview.c
+++ b/base/applications/regedit/listview.c
@@ -20,9 +20,9 @@
#include "regedit.h"
-#define CX_ICON 16
-#define CY_ICON 16
-#define NUM_ICONS 2
+#define CX_ICON 16
+#define CY_ICON 16
+#define LISTVIEW_NUM_ICONS 2
int Image_String = 0;
int Image_Bin = 0;
@@ -284,7 +284,7 @@ static BOOL InitListViewImageLists(HWND hwndLV)
/* Create the image list. */
if ((himl = ImageList_Create(CX_ICON, CY_ICON,
- ILC_MASK, 0, NUM_ICONS)) == NULL)
+ ILC_MASK, 0, LISTVIEW_NUM_ICONS)) == NULL)
{
return FALSE;
}
@@ -296,7 +296,7 @@ static BOOL InitListViewImageLists(HWND hwndLV)
Image_String = ImageList_AddIcon(himl, hico);
/* Fail if not all of the images were added. */
- if (ImageList_GetImageCount(himl) < NUM_ICONS)
+ if (ImageList_GetImageCount(himl) < LISTVIEW_NUM_ICONS)
{
return FALSE;
}
diff --git a/base/applications/regedit/childwnd.c b/base/applications/regedit/childwnd.c
index 0036536b91..d3a6cd0c5b 100644
--- a/base/applications/regedit/childwnd.c
+++ b/base/applications/regedit/childwnd.c
@@ -118,13 +118,13 @@ static void finish_splitbar(HWND hWnd, int x)
/*******************************************************************************
*
* FUNCTION: _CmdWndProc(HWND, unsigned, WORD, LONG)
*
* PURPOSE: Processes WM_COMMAND messages for the main frame window.
*
*/
-static BOOL _CmdWndProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
+static BOOL ChildWnd_CmdWndProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
{
HTREEITEM hSelection;
HKEY hRootKey;
@@ -426,7 +426,7 @@ LRESULT CALLBACK ChildWndProc(HWND hWnd, UINT message, WPARAM wParam,
LPARAM lPa
PostMessageW(g_pChildWnd->hAddressBarWnd, WM_KEYUP, VK_RETURN, 0);
}
- if (!_CmdWndProc(hWnd, message, wParam, lParam))
+ if (!ChildWnd_CmdWndProc(hWnd, message, wParam, lParam))
{
goto def;
}
@@ -118,13 +118,13 @@ static void finish_splitbar(HWND hWnd, int x)
/*******************************************************************************
*
- * FUNCTION: _CmdWndProc(HWND, unsigned, WORD, LONG)
+ * FUNCTION: ChildWnd_CmdWndProc(HWND, unsigned, WORD, LONG)
*
* PURPOSE: Processes WM_COMMAND messages for the main frame window.